@@ -1,19 +1,22 @@
+"""
+This file contains various versions of losses using the Structural Similarity Index Measure.
+
+See https://en.wikipedia.org/wiki/Structural_similarity for more details
+
+"""
+
 import torch
 from pytorch_msssim import SSIM, MS_SSIM
 from torch import nn as nn
 
-"""
-
-This file contains various versions of losses using the Structural Similarity Index Measure described more here:
-https://en.wikipedia.org/wiki/Structural_similarity
-
-"""
-
 
 class SSIMLoss(nn.Module):
+    """SSIM Loss, optionally converting input range from [-1,1] to [0,1]"""
+
     def __init__(self, convert_range: bool = False, **kwargs):
         """
-        SSIM Loss, optionally converting input range from [-1,1] to [0,1]
+        Init
+
         Args:
             convert_range: Convert input from -1,1 to 0,1 range
             **kwargs: Kwargs to pass through to SSIM
@@ -23,6 +26,16 @@ class SSIMLoss(nn.Module):
         self.ssim_module = SSIM(**kwargs)
 
     def forward(self, x: torch.Tensor, y: torch.Tensor):
+        """
+        Forward method
+
+        Args:
+            x: one tensor
+            y: second tensor
+
+        Returns: SSIM loss
+
+        """
         if self.convert_range:
             x = torch.div(torch.add(x, 1), 2)
             y = torch.div(torch.add(y, 1), 2)
@@ -30,9 +43,12 @@ class SSIMLoss(nn.Module):
 
 
 class MS_SSIMLoss(nn.Module):
+    """Multi-Scale SSIM Loss, optionally converting input range from [-1,1] to [0,1]"""
+
     def __init__(self, convert_range: bool = False, **kwargs):
         """
-        Multi-Scale SSIM Loss, optionally converting input range from [-1,1] to [0,1]
+        Initialize
+
         Args:
             convert_range: Convert input from -1,1 to 0,1 range
             **kwargs: Kwargs to pass through to MS_SSIM
@@ -42,6 +58,16 @@ class MS_SSIMLoss(nn.Module):
         self.ssim_module = MS_SSIM(**kwargs)
 
     def forward(self, x: torch.Tensor, y: torch.Tensor):
+        """
+        Forward method
+
+        Args:
+            x: tensor one
+            y: tensor two
+
+        Returns:M S SSIM Loss
+
+        """
         if self.convert_range:
             x = torch.div(torch.add(x, 1), 2)
             y = torch.div(torch.add(y, 1), 2)
@@ -49,12 +75,17 @@ class MS_SSIMLoss(nn.Module):
 
 
 class SSIMLossDynamic(nn.Module):
+    """
+    SSIM Loss on only dynamic part of the images, optionally converting input range from [-1,1] to [0,1]
+
+    In Mathieu et al. to stop SSIM regressing towards the mean and predicting only the background, they only
+    run SSIM on the dynamic parts of the image. We can accomplish that by subtracting the current
+    image from the future ones
+    """
+
     def __init__(self, convert_range: bool = False, **kwargs):
         """
-        SSIM Loss on only dynamic part of the images, optionally converting input range from [-1,1] to [0,1]
-
-        In Mathieu et al. to stop SSIM regressing towards the mean and predicting only the background, they only
-        run SSIM on the dynamic parts of the image. We can accomplish that by subtracting the current image from the future ones
+        Initialize
 
         Args:
             convert_range: Whether to convert from -1,1 to 0,1 as required for SSIM
@@ -66,6 +97,8 @@ class SSIMLossDynamic(nn.Module):
 
     def forward(self, current_image: torch.Tensor, x: torch.Tensor, y: torch.Tensor):
         """
+        Forward method
+
         Args:
             current_image: The last 'real' image given to the mode
             x: The target future sequence
@@ -82,4 +115,4 @@ class SSIMLossDynamic(nn.Module):
         x = x - current_image
         y = y - current_image
         # TODO: Mask out loss from pixels that don't change
-        return 1.0 - self.ssim_module(x, y)
\ No newline at end of file
+        return 1.0 - self.ssim_module(x, y)
