@@ -1,11 +1,17 @@
+"""
+File containing different normalization methods
+"""
+
 import numpy as np
 
 
 def metnet_normalization(data: np.ndarray) -> np.ndarray:
     """
-    Perform the normalization used in the MetNet paper on the GOES data
+    Perform normalization from the MetNet paper
+
     This involves subtracting by the median, dividing by the interquartile range,
     then squashing to [-1,1] with the hyperbolic tangent
+
     Args:
         data: input image data
 
@@ -25,4 +31,15 @@ def metnet_normalization(data: np.ndarray) -> np.ndarray:
 
 
 def standard_normalization(data: np.ndarray, std: np.ndarray, mean: np.ndarray) -> np.ndarray:
+    """
+    Performs standard normalization to get values with a mean of 0 and standard deviation of 1
+
+    Args:
+        data: The data to normalize
+        std: Standard deviation of each channel
+        mean: Mean of each channel
+
+    Returns:
+        The normalized data
+    """
     return (data - mean) / std
